@@ -35,13 +35,13 @@
 /**                                                        **/
 /**   AUTHOR     : Francois PELLEGRINI                     **/
 /**                                                        **/
-/**   FUNCTION   : This module construct a band graph      **/
-/**                around the frontier in order to         **/
-/**                decrease problem size during            **/
-/**                uncoarsening refinement.                **/
+/**   FUNCTION   : This module builds a band graph around  **/
+/**                the frontier in order to decrease       **/
+/**                problem size for the strategy to be     **/
+/**                applied.                                **/
 /**                                                        **/
 /**   DATES      : # Version 5.0  : from : 27 nov 2006     **/
-/**                                 to   : 10 sep 2007     **/
+/**                                 to   : 23 dec 2007     **/
 /**                                                        **/
 /************************************************************/
 
@@ -249,6 +249,7 @@ const BgraphBipartBdParam * const paraptr)        /*+ Method parameters +*/
                      &bndgrafdat.s.verttax, (size_t) ((bndvertnbr + 3) * sizeof (Gnum)),
                      &bndgrafdat.s.velotax, (size_t) ((bndvertnbr + 2) * sizeof (Gnum)),
                      &bndveextax,           (size_t) (bndveexnbr       * sizeof (Gnum)),
+                     &bndgrafdat.frontab,   (size_t) ((bndvertnbr + 2) * sizeof (Gnum)),
                      &bndgrafdat.parttax,   (size_t) ((bndvertnbr + 2) * sizeof (GraphPart)), NULL) == NULL) {
     errorPrint ("bgraphBipartBd: out of memory (2)");
     memFree    (queudat.qtab);
@@ -259,7 +260,7 @@ const BgraphBipartBdParam * const paraptr)        /*+ Method parameters +*/
   bndgrafdat.s.vendtax  = bndgrafdat.s.verttax + 1; /* Band graph is compact */
   bndgrafdat.s.velotax -= orggrafptr->s.baseval;
   bndgrafdat.s.vnumtax  = bndvnumtax;             /* Will not be freed as graph vertex arrays are said to be grouped          */
-  bndgrafdat.s.velosum  = orggrafptr->s.velosum;  /* From now on we should free a Vgraph and not a Graph                      */
+  bndgrafdat.s.velosum  = orggrafptr->s.velosum;  /* From now on we should free a Bgraph and not a Graph                      */
   bndgrafdat.s.velotax[bndvertnnd]     = orggrafptr->compload0 - (bndvelosum - bndcompload1); /* Set loads of anchor vertices */
   bndgrafdat.s.velotax[bndvertnnd + 1] = orggrafptr->s.velosum - orggrafptr->compload0 - bndcompload1;
   if (bndveexnbr != 0) {
@@ -449,8 +450,6 @@ const BgraphBipartBdParam * const paraptr)        /*+ Method parameters +*/
     bndgrafdat.s.edlotax  = bndgrafdat.s.edgetax + bndedlooftval; /* Use old index into old array as new index */
   }
 
-  bndgrafdat.frontab = queudat.qtab + bndgrafdat.s.vertnbr; /* Recycle end of queue array and part of index array as band frontier array */
-
   for (bndfronnum = 0, bndvertnum = orggrafptr->s.baseval; /* Fill band frontier array with first vertex indices as they make the separator */
        bndfronnum < orggrafptr->fronnbr; bndfronnum ++, bndvertnum ++)
     bndgrafdat.frontab[bndfronnum] = bndvertnum;
@@ -505,7 +504,6 @@ const BgraphBipartBdParam * const paraptr)        /*+ Method parameters +*/
   if ((graphCheck (&bndgrafdat.s) != 0) ||        /* Check band graph consistency */
       (bgraphCheck (&bndgrafdat)  != 0)) {
     errorPrint ("bgraphBipartBd: inconsistent band graph data");
-    bndgrafdat.frontab = NULL;                    /* Do not free frontab as it is not allocated */
     bgraphExit (&bndgrafdat);
     memFree    (queudat.qtab);
     return     (1);
@@ -514,14 +512,12 @@ const BgraphBipartBdParam * const paraptr)        /*+ Method parameters +*/
 
   if (bgraphBipartSt (&bndgrafdat, paraptr->stratbnd) != 0) { /* Apply strategy to band graph */
     errorPrint ("bgraphBipartBd: cannot bipartition band graph");
-    bndgrafdat.frontab = NULL;                    /* Do not free frontab as it is not allocated */
     bgraphExit (&bndgrafdat);
     memFree    (queudat.qtab);
     return     (1);
   }
   if (bndgrafdat.parttax[bndvertnnd] ==           /* If band graph was too small and anchors went to the same part, apply strategy on full graph */
       bndgrafdat.parttax[bndvertnnd + 1]) {
-    bndgrafdat.frontab = NULL;                    /* Do not free frontab as it is not allocated */
     bgraphExit (&bndgrafdat);
     memFree    (queudat.qtab);
     return     (bgraphBipartSt (orggrafptr, paraptr->stratorg));
@@ -543,12 +539,8 @@ const BgraphBipartBdParam * const paraptr)        /*+ Method parameters +*/
   else
     orggrafptr->compsize0 = orggrafptr->compsize0 - (bndvertnbr - bndcompsize1) + bndgrafdat.compsize0 - 1; /* "- 1" for anchor 0 */
 
-  for (bndvertnum = bndgrafdat.s.baseval; bndvertnum < bndvertnnd; bndvertnum ++) { /* Update part array of full graph */
-    GraphPart           bndpartval;
-
-    bndpartval = bndgrafdat.parttax[bndvertnum];
-    orggrafptr->parttax[bndvnumtax[bndvertnum]] = bndpartval;
-  }
+  for (bndvertnum = bndgrafdat.s.baseval; bndvertnum < bndvertnnd; bndvertnum ++) /* Update part array of full graph */
+    orggrafptr->parttax[bndvnumtax[bndvertnum]] = bndgrafdat.parttax[bndvertnum];
 
   for (bndfronnum = orgfronnum = ancfronnum = 0;  /* Update frontier array of full graph */
        bndfronnum < bndgrafdat.fronnbr; bndfronnum ++) {
@@ -591,7 +583,6 @@ const BgraphBipartBdParam * const paraptr)        /*+ Method parameters +*/
 #ifdef SCOTCH_DEBUG_BGRAPH2
           if (orggrafptr->parttax[orgvertend] != ancpartval) { /* Original vertex should always be in same part as anchor */
             errorPrint ("bgraphBipartBd: internal error (10)");
-            bndgrafdat.frontab = NULL;            /* Do not free frontab as it is not allocated */
             bgraphExit (&bndgrafdat);
             memFree    (queudat.qtab);
             return     (1);
@@ -605,8 +596,7 @@ const BgraphBipartBdParam * const paraptr)        /*+ Method parameters +*/
   }
   orggrafptr->fronnbr = orgfronnum;
 
-  bndgrafdat.frontab = NULL;                      /* Do not free frontab as it is not allocated */
-  bgraphExit (&bndgrafdat);                       /* Free band graph structures                 */
+  bgraphExit (&bndgrafdat);                       /* Free band graph structures */
   memFree    (queudat.qtab);
 
 #ifdef SCOTCH_DEBUG_BGRAPH2
