@@ -1,4 +1,4 @@
-/* Copyright 2004,2007 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -49,6 +49,8 @@
 /**                                 to   : 03 feb 2000     **/
 /**                # Version 4.0  : from : 09 feb 2004     **/
 /**                                 to   : 23 nov 2005     **/
+/**                # Version 5.0  : from : 23 dec 2007     **/
+/**                                 to   : 16 mar 2008     **/
 /**                                                        **/
 /************************************************************/
 
@@ -58,8 +60,8 @@
 
 #define ATST
 
-#include "common.h"
 #include "module.h"
+#include "common.h"
 #include "scotch.h"
 #include "arch.h"
 #include "arch_deco.h"
@@ -113,10 +115,9 @@ char *              argv[];
 
   for (i = 0; i < C_FILENBR; i ++)                /* Set default stream pointers */
     C_fileTab[i].pntr = (C_fileTab[i].mode[0] == 'r') ? stdin : stdout;
-  for (i = 1; i < argc; i ++) {                   /* Loop for all option codes */
-    if ((argv[i][0] != '+') &&                    /* If found a file name      */
-        ((argv[i][0] != '-') || (argv[i][1] == '\0'))) {
-      if (C_fileNum < C_FILEARGNBR)               /* File name has been given */
+  for (i = 1; i < argc; i ++) {                   /* Loop for all option codes                        */
+    if ((argv[i][0] != '-') || (argv[i][1] == '\0') || (argv[i][1] == '.')) { /* If found a file name */
+      if (C_fileNum < C_FILEARGNBR)               /* File name has been given                         */
         C_fileTab[C_fileNum ++].name = argv[i];
       else {
         errorPrint ("main: too many file names given");
@@ -131,7 +132,7 @@ char *              argv[];
           return     (0);
         case 'V' :
           fprintf (stderr, "atst, version %s - F. Pellegrini\n", SCOTCH_VERSION);
-          fprintf (stderr, "Copyright 2004,2007 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
@@ -141,15 +142,7 @@ char *              argv[];
     }
   }
 
-  for (i = 0; i < C_FILENBR; i ++) {              /* For all file names     */
-    if ((C_fileTab[i].name[0] != '-') ||          /* If not standard stream */
-        (C_fileTab[i].name[1] != '\0')) {
-      if ((C_fileTab[i].pntr = fopen (C_fileTab[i].name, C_fileTab[i].mode)) == NULL) { /* Open the file */
-        errorPrint ("main: cannot open file (%d)", i);
-        return     (1);
-      }
-    }
-  }
+  fileBlockOpen (C_fileTab, C_FILENBR);           /* Open all files */
 
   archInit (&archdat);                            /* Initialize architecture structure */
   archLoad (&archdat, C_filepntrtgtinp);          /* Load architecture                 */
@@ -157,7 +150,7 @@ char *              argv[];
     errorPrint ("main: architecture is not decomposition-defined");
     return     (1);
   }
-  deco = (ArchDeco *) &archdat.data.dummy;        /* Point to the decomposition */
+  deco = (ArchDeco *) (void *) &archdat.data.dummy; /* Point to the decomposition */
 
   dstmin = (Anum) (((unsigned long) ((Anum) -1)) >> 1); /* Set to maximum number in Anum */
   dstmax = 0;
@@ -192,21 +185,17 @@ char *              argv[];
   if (deco->domtermnbr > 1)
     dstdlt /= (double) (deco->domtermnbr * (deco->domtermnbr - 1) / 2);
 
-  fprintf (C_filepntrlogout, "A\tTerminals\tnbr=%u\n",
-           deco->domtermnbr);
-  fprintf (C_filepntrlogout, "A\tDistance\tmin=%u\tmax=%u\tavg=%g\tdlt=%g\n",
-           dstmin, dstmax, dstavg, dstdlt);
+  fprintf (C_filepntrlogout, "A\tTerminals\tnbr=%ld\n",
+           (long) deco->domtermnbr);
+  fprintf (C_filepntrlogout, "A\tDistance\tmin=%ld\tmax=%ld\tavg=%g\tdlt=%g\n",
+           (long) dstmin, (long) dstmax, dstavg, dstdlt);
+
+  fileBlockClose (C_fileTab, C_FILENBR);          /* Always close explicitely to end eventual (un)compression tasks */
 
-#ifdef SCOTCH_DEBUG_MAIN1
   archExit (&archdat);
 
-  for (i = 0; i < C_FILENBR; i ++) {              /* For all file names     */
-    if ((C_fileTab[i].name[0] != '-') ||          /* If not standard stream */
-        (C_fileTab[i].name[1] != '\0')) {
-      fclose (C_fileTab[i].pntr);                 /* Close the stream */
-    }
-  }
-#endif /* SCOTCH_DEBUG_MAIN1 */
-
+#ifdef COMMON_PTHREAD
+  pthread_exit ((void *) 0);                      /* Allow potential (un)compression tasks to complete */
+#endif /* COMMON_PTHREAD */
   return (0);
 }
