@@ -1,4 +1,4 @@
-/* Copyright 2007 ENSEIRB, INRIA & CNRS
+/* Copyright 2007,2008 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -39,7 +39,7 @@
 /**                distributed source graphs.              **/
 /**                                                        **/
 /**   DATES      : # Version 5.0  : from : 23 jun 2007     **/
-/**                                 to   : 24 jun 2007     **/
+/**                                 to   : 16 jun 2008     **/
 /**                                                        **/
 /************************************************************/
 
@@ -50,6 +50,7 @@
 #define DGTST
 #define SCOTCH_PTSCOTCH
 
+#include "module.h"
 #include "common.h"
 #include "ptscotch.h"
 #include "dgtst.h"
@@ -81,8 +82,6 @@ main (
 int                 argc,
 char *              argv[])
 {
-  int                 thrdlvlreqval;
-  int                 thrdlvlproval;
   SCOTCH_Dgraph       grafdat;
   int                 procglbnbr;
   int                 proclocnum;
@@ -105,23 +104,34 @@ char *              argv[])
   double              edlodlt;
   int                 flagval;
   int                 i;
+#ifdef SCOTCH_PTHREAD
+  int                 thrdlvlreqval;
+  int                 thrdlvlproval;
+#endif /* SCOTCH_PTHREAD */
 
+  errorProg ("dgtst");
+
+#ifdef SCOTCH_PTHREAD
   thrdlvlreqval = MPI_THREAD_MULTIPLE;
   if (MPI_Init_thread (&argc, &argv, thrdlvlreqval, &thrdlvlproval) != MPI_SUCCESS) {
     errorPrint ("main: Cannot initialize (1)");
     exit       (1);
   }
   if (thrdlvlreqval > thrdlvlproval) {
+    errorPrint ("main: MPI implementation is not thread-safe: recompile without SCOTCH_PTHREAD");
+    exit       (1);
+  }
+#else /* SCOTCH_PTHREAD */
+  if (MPI_Init (&argc, &argv) != MPI_SUCCESS) {
     errorPrint ("main: Cannot initialize (2)");
     exit       (1);
   }
+#endif /* SCOTCH_PTHREAD */
 
   MPI_Comm_size (MPI_COMM_WORLD, &procglbnbr);    /* Get communicator data */
   MPI_Comm_rank (MPI_COMM_WORLD, &proclocnum);
   protglbnum = 0;                                 /* Assume root process is process 0 */
 
-  errorProg ("dgtst");
-
   if ((argc >= 2) && (argv[1][0] == '?')) {       /* If need for help */
     usagePrint (stdout, C_usageList);
     return     (0);
@@ -167,7 +177,7 @@ char *              argv[])
         case 'V' :
         case 'v' :
           fprintf (stderr, "dgtst, version %s - F. Pellegrini\n", SCOTCH_VERSION);
-          fprintf (stderr, "Copyright 2007 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "Copyright 2007,2008 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
@@ -190,23 +200,7 @@ char *              argv[])
   }
 #endif /* SCOTCH_DEBUG_ALL */
 
-  for (i = 0; i < C_FILENBR; i ++) {              /* For all file names */
-    if (fileNameDistExpand (&C_fileTab[i].name, procglbnbr, proclocnum, protglbnum) != 0) { /* If cannot allocate new name */
-      errorPrint ("main: cannot create file name (%d)", i);
-      return     (1);
-    }
-    if (C_fileTab[i].name == NULL)                /* If inexisting stream because not root process and centralized stream */
-      C_fileTab[i].pntr = NULL;
-    else {
-      if ((C_fileTab[i].name[0] != '-') ||        /* If not standard stream, open it */
-          (C_fileTab[i].name[1] != '\0')) {
-        if ((C_fileTab[i].pntr = fopen (C_fileTab[i].name, C_fileTab[i].mode)) == NULL) { /* Open the file */
-          errorPrint ("main: cannot open file (%d)", i);
-          return     (1);
-        }
-      }
-    }
-  }
+  fileBlockOpenDist (C_fileTab, C_FILENBR, procglbnbr, proclocnum, protglbnum); /* Open all files */
 
   SCOTCH_dgraphInit  (&grafdat, MPI_COMM_WORLD);
   SCOTCH_dgraphLoad  (&grafdat, C_filepntrsrcinp, -1, 0);
@@ -218,29 +212,25 @@ char *              argv[])
                      &edlomin, &edlomax, &edlosum, &edloavg, &edlodlt);
 
   if (C_filepntrdatout != NULL) {
-    fprintf (C_filepntrdatout, "S\tVertex\tnbr=%u\n",
-             vertnbr);
-    fprintf (C_filepntrdatout, "S\tVertex load\tmin=%u\tmax=%u\tsum=%u\tavg=%g\tdlt=%g\n",
-             velomin, velomax, velosum, veloavg, velodlt);
-    fprintf (C_filepntrdatout, "S\tVertex degree\tmin=%u\tmax=%u\tsum=%u\tavg=%g\tdlt=%g\n",
-             degrmin, degrmax, edgenbr, degravg, degrdlt);
-    fprintf (C_filepntrdatout, "S\tEdge\tnbr=%u\n",
-             edgenbr / 2);
-    fprintf (C_filepntrdatout, "S\tEdge load\tmin=%u\tmax=%u\tsum=%u\tavg=%g\tdlt=%g\n",
-             edlomin, edlomax, edlosum, edloavg, edlodlt);
+    fprintf (C_filepntrdatout, "S\tVertex\tnbr=%ld\n",
+             (long) vertnbr);
+    fprintf (C_filepntrdatout, "S\tVertex load\tmin=%ld\tmax=%ld\tsum=%ld\tavg=%g\tdlt=%g\n",
+             (long) velomin, (long) velomax, (long) velosum, veloavg, velodlt);
+    fprintf (C_filepntrdatout, "S\tVertex degree\tmin=%ld\tmax=%ld\tsum=%ld\tavg=%g\tdlt=%g\n",
+             (long) degrmin, (long) degrmax, (long) edgenbr, degravg, degrdlt);
+    fprintf (C_filepntrdatout, "S\tEdge\tnbr=%ld\n",
+             (long) (edgenbr / 2));
+    fprintf (C_filepntrdatout, "S\tEdge load\tmin=%ld\tmax=%ld\tsum=%ld\tavg=%g\tdlt=%g\n",
+             (long) edlomin, (long) edlomax, (long) edlosum, edloavg, edlodlt);
   }
-#ifdef SCOTCH_DEBUG_ALL
+
+  fileBlockClose (C_fileTab, C_FILENBR);          /* Always close explicitely to end eventual (un)compression tasks */
+
   SCOTCH_dgraphExit (&grafdat);
 
-  for (i = 0; i < C_FILENBR; i ++) {              /* For all file names     */
-    if ((C_fileTab[i].name != NULL) &&            /* If existing stream     */
-        ((C_fileTab[i].name[0] != '-') ||         /* If not standard stream */
-         (C_fileTab[i].name[1] != '\0'))) {
-      fclose (C_fileTab[i].pntr);                 /* Close the stream */
-    }
-  }
-#endif /* SCOTCH_DEBUG_ALL */
-
   MPI_Finalize ();
-  exit         (0);
+#ifdef COMMON_PTHREAD
+  pthread_exit ((void *) 0);                      /* Allow potential (un)compression tasks to complete */
+#endif /* COMMON_PTHREAD */
+  return (0);
 }
