@@ -1,4 +1,4 @@
-/* Copyright 2004,2007 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -54,6 +54,8 @@
 /**                                 to     08 feb 2004     **/
 /**                # Version 5.0  : from : 25 may 2007     **/
 /**                                 to     25 may 2007     **/
+/**                # Version 5.1  : from : 25 oct 2007     **/
+/**                                 to     16 mar 2008     **/
 /**                                                        **/
 /************************************************************/
 
@@ -63,6 +65,7 @@
 
 #define GOUT
 
+#include "module.h"
 #include "common.h"
 #include "scotch.h"
 #include "gout_c.h"
@@ -112,6 +115,13 @@ static const char *         C_usageList[] = {     /* Usage */
   "                          x=<val>  : minimum x clipping ratio",
   "                          Y=<val>  : maximum y clipping ratio",
   "                          y=<val>  : minimum y clipping ratio",
+  "  -Ot[{<arguments>}]  : Tulip graph file :",
+  "                          b        : b/w output",
+  "                          c        : color output",
+  "                          r        : remove cut edges",
+  "                          v        : view cut edges",
+  "                          a        : avoid displaying disks",
+  "                          d        : display disks",
   "  -V                  : Print program version and copyright",
   "",
   "Default option set is : -Oi{c,v}",
@@ -142,10 +152,9 @@ char *                      argv[])
 
   for (i = 0; i < C_FILENBR; i ++)                /* Set default stream pointers */
     C_fileTab[i].pntr = (C_fileTab[i].mode[0] == 'r') ? stdin : stdout;
-  for (i = 1; i < argc; i ++) {                   /* Loop for all option codes */
-    if ((argv[i][0] != '+') &&                    /* If found a file name      */
-        ((argv[i][0] != '-') || (argv[i][1] == '\0'))) {
-      if (C_fileNum < C_FILEARGNBR)               /* File name has been given */
+  for (i = 1; i < argc; i ++) {                   /* Loop for all option codes                        */
+    if ((argv[i][0] != '-') || (argv[i][1] == '\0') || (argv[i][1] == '.')) { /* If found a file name */
+      if (C_fileNum < C_FILEARGNBR)               /* File name has been given                         */
         C_fileTab[C_fileNum ++].name = argv[i];
       else {
         errorPrint ("main: too many file names given");
@@ -183,7 +192,7 @@ char *                      argv[])
           break;
         case 'V' :
           fprintf (stderr, "gout, version %s - F. Pellegrini\n", SCOTCH_VERSION);
-          fprintf (stderr, "Copyright 2004,2007 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
@@ -193,15 +202,7 @@ char *                      argv[])
     }
   }
 
-  for (i = 0; i < C_FILENBR; i ++) {              /* For all file names     */
-    if ((C_fileTab[i].name[0] != '-') ||          /* If not standard stream */
-        (C_fileTab[i].name[1] != '\0')) {
-      if ((C_fileTab[i].pntr = fopen (C_fileTab[i].name, C_fileTab[i].mode)) == NULL) { /* Open the file */
-        errorPrint ("main: cannot open file (%d)", i);
-        return     (1);
-      }
-    }
-  }
+  fileBlockOpen (C_fileTab, C_FILENBR);           /* Open all files */
 
   SCOTCH_graphInit (&grafdat.grafdat);            /* Create graph structure         */
   SCOTCH_graphLoad (&grafdat.grafdat, C_filepntrsrcinp, 0, 3); /* Read source graph */
@@ -218,19 +219,15 @@ char *                      argv[])
 
   outDraw (&grafdat, &geo, &map, C_filepntrdatout); /* Build and write the output */
 
-#ifdef SCOTCH_DEBUG_MAIN1
+  fileBlockClose (C_fileTab, C_FILENBR);          /* Always close explicitely to end eventual (un)compression tasks */
+
   C_mapExit        (&map);                        /* Free data structures */
   C_geoExit        (&geo);
-  SCOTCH_graphExit (&grafdat);
-
-  for (i = 0; i < C_FILENBR; i ++) {              /* For all file names     */
-    if ((C_fileTab[i].name[0] != '-') ||          /* If not standard stream */
-        (C_fileTab[i].name[1] != '\0')) {
-      fclose (C_fileTab[i].pntr);                 /* Close the stream */
-    }
-  }
-#endif /* SCOTCH_DEBUG_MAIN1 */
+  SCOTCH_graphExit (&grafdat.grafdat);
 
+#ifdef COMMON_PTHREAD
+  pthread_exit ((void *) 0);                      /* Allow potential (un)compression tasks to complete */
+#endif /* COMMON_PTHREAD */
   return (0);
 }
 
@@ -682,18 +679,19 @@ int
 C_parse (
 const C_ParseCode * const   codeptr,             /* Pointer to the code array          */
 const C_ParseArg * const    argptr,              /* Pointer to the code argument array */
-uint * const                codeval,             /* Pointer to the code value to set   */
+int * const                 codeval,             /* Pointer to the code value to set   */
 char * const                string)              /* Pointer to the string to parse     */
 {
-  uint                code;                      /* Code found                       */
-  uint                codelen;                   /* Code name length                 */
+  int                 code;                      /* Code found                       */
+  int                 codelen;                   /* Code name length                 */
   char                argbuf[128];               /* Buffer for argument scanning     */
-  uint                arglen;                    /* Length of the current argument   */
+  int                 arglen;                    /* Length of the current argument   */
   char *              argbeg;                    /* Pointer to beginning of argument */
   char *              argend;                    /* Pointer to end of argument       */
   char *              argequ;                    /* Position of the '=' character    */
-  uint                i, j;
+  int                 i, j;
 
+  code    =
   codelen = 0;                                   /* No code recognized yet              */
   for (i = 0; codeptr[i].name != NULL; i ++) {   /* For all the codes                   */
     if ((strncasecmp (string,                    /* Find the longest matching code name */
@@ -716,7 +714,7 @@ char * const                string)              /* Pointer to the string to par
       if (*argend == '\0')                       /* If there is no end delimiter      */
         return (3);                              /* Return the syntax error value     */
 
-      arglen = ((argend - argbeg) < 127)         /* Get argument bounded length   */
+      arglen = ((argend - argbeg) < 127)         /* Get argument bounded length */
                ? (argend - argbeg)
                : 127;
       strncpy (argbuf, argbeg, arglen);          /* Copy the argument to the buffer */
@@ -725,16 +723,14 @@ char * const                string)              /* Pointer to the string to par
       if (argequ != NULL)                        /* If it exists                    */
         *argequ++ = '\0';                        /* Turn it into a separating null  */
 
-      for (i = 0, j = (unsigned int) -1;         /* Scan all the possible arguments */
-           argptr[i].name != NULL;
-           i ++) {
-        if ((argptr[i].code == code) &&          /* If the proper name is found */
+      for (i = 0, j = -1; argptr[i].name != NULL; i ++) { /* Scan all the possible arguments */
+        if ((argptr[i].code == code) &&          /* If the proper name is found              */
             (strcmp (argbuf, argptr[i].name) == 0)) {
           j = i;                                 /* Record the position */
           break;                                 /* Exit the loop       */
         }
       }
-      if (j == (unsigned int) -1)                /* If invalid argument     */
+      if (j == -1)                               /* If invalid argument     */
         return (2);                              /* Return the proper value */
 
       if (argptr[j].format != NULL) {            /* If there is a value to read    */
