@@ -1,4 +1,4 @@
-/* Copyright 2004,2007 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -40,6 +40,8 @@
 /**                                                        **/
 /**   DATES      : # Version 4.0  : from : 26 sep 2002     **/
 /**                                 to   : 17 feb 2004     **/
+/**                # Version 5.0  : from : 13 dec 2007     **/
+/**                                 to   : 16 mar 2008     **/
 /**                                                        **/
 /**   NOTES      : # The nodes and elements of the         **/
 /**                  (dX,dY,dZ) mesh are numbered so that  **/
@@ -56,6 +58,7 @@
 
 #define MMK_M3
 
+#include "module.h"
 #include "common.h"
 #include "scotch.h"
 #include "mmk_m3.h"
@@ -95,12 +98,12 @@ char *                      argv[])
   SCOTCH_Num          n[3];                       /* Mesh node dimensions    */
   SCOTCH_Num          c[3];                       /* Vertex coordinates      */
   SCOTCH_Num          velmnbr;                    /* First node number       */
-  uint                flag;                       /* Process flags           */
+  int                 flagval;                    /* Process flags           */
   int                 i;
 
   errorProg ("mmk_m3");
 
-  flag = C_FLAGDEFAULT;                           /* Set default flags */
+  flagval = C_FLAGDEFAULT;                        /* Set default flags */
 
   if ((argc >= 2) && (argv[1][0] == '?')) {       /* If need for help */
     usagePrint (stdout, C_usageList);
@@ -109,11 +112,10 @@ char *                      argv[])
 
   for (i = 0; i < C_FILENBR; i ++)                /* Set default stream pointers */
     C_fileTab[i].pntr = (C_fileTab[i].mode[0] == 'r') ? stdin : stdout;
-  for (i = 1; i < argc; i ++) {                   /* Loop for all option codes */
-    if ((argv[i][0] != '+') &&                    /* If found a file name      */
-        ((argv[i][0] != '-') || (argv[i][1] == '\0'))) {
-      if (C_paraNum < 3) {                        /* If number of parameters not reached */
-        if ((e[C_paraNum ++] = atoi (argv[i])) < 1) { /* Get the dimension               */
+  for (i = 1; i < argc; i ++) {                   /* Loop for all option codes                        */
+    if ((argv[i][0] != '-') || (argv[i][1] == '\0') || (argv[i][1] == '.')) { /* If found a file name */
+      if (C_paraNum < 3) {                        /* If number of parameters not reached              */
+        if ((e[C_paraNum ++] = atoi (argv[i])) < 1) { /* Get the dimension                            */
           errorPrint ("main: invalid dimension (\"%s\")", argv[i]);
           return     (1);
         }
@@ -130,7 +132,7 @@ char *                      argv[])
       switch (argv[i][1]) {
         case 'G' :                                /* Output mesh geometry */
         case 'g' :
-          flag |= C_FLAGGEOOUT;
+          flagval |= C_FLAGGEOOUT;
           if (argv[i][2] != '\0')
             C_filenamegeoout = &argv[i][2];
           break;
@@ -140,7 +142,7 @@ char *                      argv[])
           return     (0);
         case 'V' :
           fprintf (stderr, "mmk_m3, version %s - F. Pellegrini\n", SCOTCH_VERSION);
-          fprintf (stderr, "Copyright 2004,2007 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
@@ -150,15 +152,7 @@ char *                      argv[])
     }
   }
 
-  for (i = 0; i < C_FILENBR; i ++) {              /* For all file names     */
-    if ((C_fileTab[i].name[0] != '-') ||          /* If not standard stream */
-        (C_fileTab[i].name[1] != '\0')) {
-      if ((C_fileTab[i].pntr = fopen (C_fileTab[i].name, C_fileTab[i].mode)) == NULL) { /* Open the file */
-        errorPrint ("main: cannot open file (%d)", i);
-        return     (1);
-      }
-    }
-  }
+  fileBlockOpen (C_fileTab, C_FILENBR);           /* Open all files */
 
   n[0] = e[0] + 1;
   n[1] = e[1] + 1;
@@ -235,7 +229,7 @@ char *                      argv[])
     }
   }
 
-  if (flag & C_FLAGGEOOUT) {                      /* If geometry is wanted       */
+  if (flagval & C_FLAGGEOOUT) {                   /* If geometry is wanted       */
     fprintf (C_filepntrgeoout, "3\n%ld\n",        /* Output geometry file header */
               (long) (velmnbr + n[0] * n[1] * n[2]));
 
@@ -261,14 +255,10 @@ char *                      argv[])
     }
   }
 
-#ifdef SCOTCH_DEBUG_MAIN1
-  for (i = 0; i < C_FILENBR; i ++) {              /* For all file names     */
-    if ((C_fileTab[i].name[0] != '-') ||          /* If not standard stream */
-        (C_fileTab[i].name[1] != '\0')) {
-      fclose (C_fileTab[i].pntr);                 /* Close the stream */
-    }
-  }
-#endif /* SCOTCH_DEBUG_MAIN1 */
+  fileBlockClose (C_fileTab, C_FILENBR);          /* Always close explicitely to end eventual (un)compression tasks */
 
+#ifdef COMMON_PTHREAD
+  pthread_exit ((void *) 0);                      /* Allow potential (un)compression tasks to complete */
+#endif /* COMMON_PTHREAD */
   return (0);
 }
